@@ -9,9 +9,12 @@ register = Library()
 @register.inclusion_tag('attachments/add_form.html', takes_context=True)
 def attachment_form(context, obj):
     """
-    Renders a "upload attachment" form
+    Renders a "upload attachment" form.
+    
+    The user must own ``attachments.add_attachment permission`` to add
+    attachments.
     """
-    if context['user'].is_authenticated():
+    if context['user'].has_perm('attachments.add_attachment'):
         return {
             'form': AttachmentForm(),
             'form_url': add_url_for_obj(obj),
@@ -26,11 +29,16 @@ def attachment_form(context, obj):
 def attachment_delete_link(context, attachment):
     """
     Renders a html link to the delete view of the given attachment. Returns
-    no content if the request-user has no permission to delete foreign
+    no content if the request-user has no permission to delete attachments.
+    
+    The user must own either the ``attachments.delete_attachment`` permission
+    and is the creator of the attachment, that he can delete it or he has
+    ``attachments.delete_foreign_attachments`` which allows him to delete all
     attachments.
     """
     if context['user'].has_perm('delete_foreign_attachments') \
-       or context['user'] == attachment.creator:
+       or (context['user'] == attachment.creator and \
+           context['user'].has_perm('attachments.delete_attachment')):
         return {
             'next': context['request'].build_absolute_uri(),
             'delete_url': reverse('delete_attachment', kwargs={'attachment_pk': attachment.pk})
